@@ -24,7 +24,7 @@
 
 import gi
 gi.require_versions({"Gfm": "0.1", "Grl": "0.3"})
-from gi.repository import Gfm, Gio, Grl, GObject
+from gi.repository import Gfm, Grl, GObject
 
 from gnomemusic.artistart import ArtistArt
 import gnomemusic.utils as utils
@@ -76,7 +76,7 @@ class CoreArtist(GObject.GObject):
 
         return albums_model_sort
 
-    @GObject.Property(type=Gio.ListModel, default=None)
+    @GObject.Property(type=Gfm.SortListModel, default=None)
     def model(self):
         if self._model is None:
             self._model = self._get_artist_album_model()
@@ -111,11 +111,11 @@ class CoreArtist(GObject.GObject):
     def thumbnail(self):
         """Artist art thumbnail retrieval
 
-        :return: The artist art uri or "generic" or "loading"
+        :return: The artist art uri or "generic"
         :rtype: string
         """
         if self._thumbnail is None:
-            self._thumbnail = "loading"
+            self._thumbnail = "generic"
             ArtistArt(self._application, self)
 
         return self._thumbnail
@@ -124,6 +124,6 @@ class CoreArtist(GObject.GObject):
     def thumbnail(self, value):
         """Artist art thumbnail setter
 
-        :param string value: uri, "generic" or "loading"
+        :param string value: uri or "generic"
         """
         self._thumbnail = value
