@@ -28,7 +28,7 @@ from gettext import gettext as _
 
 import gi
 gi.require_versions({"Grl": "0.3"})
-from gi.repository import Gio, Grl, GLib, GObject
+from gi.repository import Gio, Grl, GLib, GObject, Tracker
 
 from gnomemusic.coresong import CoreSong
 import gnomemusic.utils as utils
@@ -200,7 +200,18 @@ class GrlTrackerPlaylists(GObject.GObject):
         :param callback: function to perform once, the playlist is created
         """
         def _create_cb(conn, res, data):
-            result = conn.update_blank_finish(res)
+            try:
+                result = conn.update_blank_finish(res)
+            except GLib.Error as error:
+                self._log.warning(
+                    "Unable to create playlist {}: {}".format(
+                        playlist_title, error.message))
+                self._notificationmanager.pop_loading()
+                if callback is not None:
+                    callback(None)
+
+                return
+
             playlist_urn = result[0][0]['playlist']
             query = """
             SELECT
@@ -230,7 +241,9 @@ class GrlTrackerPlaylists(GObject.GObject):
                              nie:title "%(title)s" ;
                              nfo:entryCounter 0 .
             }
-            """.replace("\n", " ").strip() % {"title": playlist_title}
+            """.replace("\n", " ").strip() % {
+                "title": Tracker.sparql_escape_string(playlist_title)
+        }
         self._tracker.update_blank_async(query, None, _create_cb, None)
 
     def check_smart_playlist_change(self):
@@ -269,6 +282,7 @@ class Playlist(GObject.GObject):
 
     count = GObject.Property(type=int, default=0)
     creation_date = GObject.Property(type=GLib.DateTime, default=None)
+    icon_name = GObject.Property(type=str, default="playlist2-symbolic")
     is_smart = GObject.Property(type=bool, default=False)
     pl_id = GObject.Property(type=str, default=None)
     query = GObject.Property(type=str, default=None)
@@ -325,7 +339,7 @@ class Playlist(GObject.GObject):
 
         return self._model
 
-    @model.setter
+    @model.setter  # type: ignore
     def model(self, value):
         self._model = value
 
@@ -432,7 +446,7 @@ class Playlist(GObject.GObject):
         """
         return self._title
 
-    @title.setter
+    @title.setter  # type: ignore
     def title(self, new_name):
         """Rename a playlist
 
@@ -468,7 +482,7 @@ class Playlist(GObject.GObject):
             )
         }
         """.replace("\n", " ").strip() % {
-            'title': new_name,
+            'title': Tracker.sparql_escape_string(new_name),
             'playlist_id': self.props.pl_id
         }
 
@@ -495,86 +509,123 @@ class Playlist(GObject.GObject):
         self._model.insert(position, coresong)
         self.props.count += 1
 
-    def finish_song_deletion(self, coresong):
+    def finish_song_deletion(self, coresong: CoreSong, position: int) -> None:
         """Removes a song from the playlist
 
         :param CoreSong coresong: song to remove
+        :param int position: Song position in the playlist, starts from
+        zero
         """
+        def update_cb(conn, res):
+            try:
+                conn.update_finish(res)
+            except GLib.Error as e:
+                self._log.warning(
+                    "Unable to remove song from playlist {}: {}".format(
+                        self.props.title, e.message))
 
-        def update_cb(conn, res, data):
-            # FIXME: Check for failure.
-            conn.update_finish(res)
             self._notificationmanager.pop_loading()
 
-        self._notificationmanager.push_loading()
-        query = """
-        INSERT OR REPLACE {
-            ?entry nfo:listPosition ?position .
+        def entry_retrieved_cb(source, op_id, media, remaining, error):
+            if error:
+                self._log.warning("Error: {}".format(error))
+                return
 
-        }
-        WHERE {
-            SELECT ?entry
-                   (?old_position - 1) AS ?position
+            if not media:
+                return
+
+            self._notificationmanager.push_loading()
+            update_query = """
+            INSERT OR REPLACE {
+                ?entry nfo:listPosition ?position .
+            }
             WHERE {
-                ?entry a nfo:MediaFileListEntry ;
-                         nfo:listPosition ?old_position .
-                ?playlist nfo:hasMediaFileListEntry ?entry .
-                FILTER (?old_position > ?removed_position)
-                {
-                    SELECT ?playlist
-                           ?removed_position
-                    WHERE {
-                        ?playlist a nmm:Playlist ;
-                                  a nfo:MediaList ;
-                                    nfo:hasMediaFileListEntry ?removed_entry .
-                        ?removed_entry nfo:listPosition ?removed_position .
-                        FILTER (
-                            tracker:id(?playlist) = %(playlist_id)s &&
-                            tracker:id(?removed_entry) = %(song_id)s
-                        )
+                SELECT ?entry
+                       (?old_position - 1) AS ?position
+                WHERE {
+                    ?entry a nfo:MediaFileListEntry ;
+                             nfo:listPosition ?old_position .
+                    ?playlist nfo:hasMediaFileListEntry ?entry .
+                    FILTER (?old_position > ?removed_position)
+                    {
+                        SELECT ?playlist
+                               ?removed_position
+                        WHERE {
+                            ?playlist a nmm:Playlist ;
+                                      a nfo:MediaList ;
+                                        nfo:hasMediaFileListEntry
+                                        ?removed_entry .
+                            ?removed_entry nfo:listPosition ?removed_position .
+                            FILTER (
+                                tracker:id(?playlist) = %(playlist_id)s &&
+                                tracker:id(?removed_entry) = %(entry_id)s
+                            )
+                        }
                     }
                 }
+            };
+            INSERT OR REPLACE {
+                ?playlist nfo:entryCounter ?new_counter .
+            }
+            WHERE {
+                SELECT ?playlist
+                       (?counter - 1) AS ?new_counter
+                WHERE {
+                    ?playlist a nmm:Playlist ;
+                              a nfo:MediaList ;
+                                nfo:entryCounter ?counter .
+                    FILTER (
+                        tracker:id(?playlist) = %(playlist_id)s
+                    )
+                }
+            };
+            DELETE {
+                ?playlist nfo:hasMediaFileListEntry ?entry .
+                ?entry a rdfs:Resource .
             }
-        };
-        INSERT OR REPLACE {
-            ?playlist nfo:entryCounter ?new_counter .
-        }
-        WHERE {
-            SELECT ?playlist
-                   (?counter - 1) AS ?new_counter
             WHERE {
                 ?playlist a nmm:Playlist ;
                           a nfo:MediaList ;
-                            nfo:entryCounter ?counter .
+                            nfo:hasMediaFileListEntry ?entry .
                 FILTER (
-                    tracker:id(?playlist) = %(playlist_id)s
+                    tracker:id(?playlist) = %(playlist_id)s &&
+                    tracker:id(?entry) = %(entry_id)s
+                )
+            }
+            """.replace("\n", " ").strip() % {
+                "playlist_id": self.props.pl_id,
+                "entry_id": media.get_id()
+            }
+
+            self._tracker.update_async(update_query, None, update_cb)
+
+        entry_query = """
+        SELECT
+            %(media_type)s AS ?type
+            ?entry AS ?id
+            WHERE {
+                ?playlist a nmm:Playlist ;
+                          a nfo:MediaList ;
+                            nfo:hasMediaFileListEntry ?entry .
+                ?entry a nfo:MediaFileListEntry .
+                FILTER (
+                    %(filter_clause_pl)s &&
+                    nfo:listPosition(?entry) = %(position)s
                 )
             }
-        };
-        DELETE {
-            ?playlist nfo:hasMediaFileListEntry ?entry .
-            ?entry a rdfs:Resource .
-        }
-        WHERE {
-            ?playlist a nmm:Playlist ;
-                      a nfo:MediaList ;
-                        nfo:hasMediaFileListEntry ?entry .
-            FILTER (
-                tracker:id(?playlist) = %(playlist_id)s &&
-                tracker:id(?entry) = %(song_id)s
-            )
-        }
         """.replace("\n", " ").strip() % {
-            "playlist_id": self.props.pl_id,
-            "song_id": coresong.props.media.get_id()
+            "media_type": int(Grl.MediaType.AUDIO),
+            "position": position + 1,
+            "filter_clause_pl": "tracker:id(?playlist) = " + self.props.pl_id,
         }
 
-        self._tracker.update_async(query, None, update_cb, None)
+        self._source.query(
+            entry_query, [Grl.METADATA_KEY_ID], self._fast_options,
+            entry_retrieved_cb)
 
     def add_songs(self, coresongs):
         """Adds songs to the playlist
 
-        :param Playlist playlist:
         :param list coresongs: list of Coresong
         """
         def _add_to_model(source, op_id, media, remaining, error):
@@ -592,6 +643,7 @@ class Playlist(GObject.GObject):
                 return
 
             media_id = coresong.props.media.get_id()
+            pl_id = self.props.pl_id
             miner_fs_busname = self._tracker_wrapper.props.miner_fs_busname
             query = """
             SELECT
@@ -619,10 +671,14 @@ class Playlist(GObject.GObject):
                             nmm:artistName(nmm:artist(?song)) AS ?artist
                             nie:title(nmm:musicAlbum(?song)) AS ?album
                             nfo:duration(?song) AS ?duration
+                            ?url
                         WHERE {
                             ?song a nmm:MusicPiece ;
                                   nie:isStoredAs ?url .
                             %(location_filter)s
+                            FILTER (
+                                %(filter_clause_song)s
+                            )
                         }
                     }
                 }
@@ -631,12 +687,13 @@ class Playlist(GObject.GObject):
                     FILTER( ?tag = nao:predefined-tag-favorite )
                 }
                 FILTER (
-                   %(filter_clause)s
+                    %(filter_clause_pl)s
                 )
-            }
+            } LIMIT 1
             """.replace("\n", " ").strip() % {
                 "media_type": int(Grl.MediaType.AUDIO),
-                "filter_clause": "tracker:id(?song) = " + media_id,
+                "filter_clause_song": "tracker:id(?song) = " + media_id,
+                "filter_clause_pl": "tracker:id(?playlist) = " + pl_id,
                 "location_filter": self._tracker_wrapper.location_filter(),
                 "miner_fs_busname": miner_fs_busname,
             }
@@ -825,6 +882,7 @@ class MostPlayed(SmartPlaylist):
         self.props.tag_text = "MOST_PLAYED"
         # TRANSLATORS: this is a playlist name
         self._title = _("Most Played")
+        self.props.icon_name = "audio-speakers-symbolic"
         self.props.query = """
         SELECT
             %(media_type)s AS ?type
@@ -878,6 +936,7 @@ class NeverPlayed(SmartPlaylist):
         self.props.tag_text = "NEVER_PLAYED"
         # TRANSLATORS: this is a playlist name
         self._title = _("Never Played")
+        self.props.icon_name = "dialog-question-symbolic"
         self.props.query = """
         SELECT
             %(media_type)s AS ?type
@@ -930,6 +989,7 @@ class RecentlyPlayed(SmartPlaylist):
         self.props.tag_text = "RECENTLY_PLAYED"
         # TRANSLATORS: this is a playlist name
         self._title = _("Recently Played")
+        self.props.icon_name = "document-open-recent-symbolic"
 
         sparql_midnight_dateTime_format = "%Y-%m-%dT00:00:00Z"
         days_difference = 7
@@ -992,6 +1052,7 @@ class RecentlyAdded(SmartPlaylist):
         self.props.tag_text = "RECENTLY_ADDED"
         # TRANSLATORS: this is a playlist name
         self._title = _("Recently Added")
+        self.props.icon_name = "list-add-symbolic"
 
         sparql_midnight_dateTime_format = "%Y-%m-%dT00:00:00Z"
         days_difference = 7
@@ -1054,6 +1115,7 @@ class Favorites(SmartPlaylist):
         self.props.tag_text = "FAVORITES"
         # TRANSLATORS: this is a playlist name
         self._title = _("Favorite Songs")
+        self.props.icon_name = "starred-symbolic"
         self.props.query = """
             SELECT
                 %(media_type)s AS ?type
