@@ -35,11 +35,10 @@ from gnomemusic.musiclogger import MusicLogger
 
 class ArtSize(Enum):
     """Enum for icon sizes"""
-    XSMALL = (34, 34)
-    SMALL = (48, 48)
-    MEDIUM = (128, 128)
+    XSMALL = (42, 42)
+    SMALL = (74, 74)
+    MEDIUM = (192, 192)
     LARGE = (256, 256)
-    XLARGE = (512, 512)
 
     def __init__(self, width, height):
         """Intialize width and height"""
@@ -136,13 +135,13 @@ def get_media_title(item):
 
 
 def get_media_year(item):
-    """Returns the year when the media was created.
+    """Returns the year when the media was published.
 
     :param Grl.Media item: A Grilo Media object
-    :return: The creation year or '----' if not defined
+    :return: The publication year or '----' if not defined
     :rtype: str
     """
-    date = item.get_creation_date()
+    date = item.get_publication_date()
 
     if not date:
         return "----"
@@ -161,7 +160,7 @@ def seconds_to_string(duration):
     minutes = seconds // 60
     seconds %= 60
 
-    return '{:d}:{:02d}'.format(minutes, seconds)
+    return '{:d}∶{:02d}'.format(minutes, seconds)
 
 
 def normalize_caseless(text):
