@@ -41,11 +41,15 @@ class AlbumsView(Gtk.Stack):
 
     __gtype_name__ = "AlbumsView"
 
+    icon_name = GObject.Property(
+        type=str, default="media-optical-cd-audio-symbolic",
+        flags=GObject.ParamFlags.READABLE)
     search_mode_active = GObject.Property(type=bool, default=False)
     selection_mode = GObject.Property(type=bool, default=False)
     title = GObject.Property(
         type=str, default=_("Albums"), flags=GObject.ParamFlags.READABLE)
 
+    _album_scrolled_window = Gtk.Template.Child()
     _scrolled_window = Gtk.Template.Child()
     _flowbox = Gtk.Template.Child()
     _flowbox_long_press = Gtk.Template.Child()
@@ -62,7 +66,7 @@ class AlbumsView(Gtk.Stack):
         self._application = application
         self._window = application.props.window
         self._headerbar = self._window._headerbar
-        self._adjustment_timeout_id = None
+        self._adjustment_timeout_id = 0
         self._viewport = self._scrolled_window.get_child()
         self._widget_counter = 1
         self._ctrl_hold = False
@@ -85,7 +89,7 @@ class AlbumsView(Gtk.Stack):
             "selection-mode", self, "selection-mode",
             GObject.BindingFlags.BIDIRECTIONAL)
 
-        self.add(self._album_widget)
+        self._album_scrolled_window.add(self._album_widget)
 
         self.connect(
             "notify::search-mode-active", self._on_search_mode_changed)
@@ -96,13 +100,13 @@ class AlbumsView(Gtk.Stack):
             "changed", self._on_vadjustment_changed)
 
     def _on_vadjustment_changed(self, adjustment):
-        if self._adjustment_timeout_id is not None:
+        if self._adjustment_timeout_id != 0:
             GLib.source_remove(self._adjustment_timeout_id)
-            self._adjustment_timeout_id = None
+            self._adjustment_timeout_id = 0
 
         self._adjustment_timeout_id = GLib.timeout_add(
             200, self._retrieve_covers, adjustment.props.value,
-            priority=GLib.PRIORITY_LOW)
+            priority=GLib.PRIORITY_DEFAULT - 10)
 
     def _retrieve_covers(self, old_adjustment):
         adjustment = self._scrolled_window.props.vadjustment.props.value
@@ -142,7 +146,7 @@ class AlbumsView(Gtk.Stack):
         for albumcover in retrieve_list:
             albumcover.retrieve()
 
-        self._adjustment_timeout_id = None
+        self._adjustment_timeout_id = 0
 
         return GLib.SOURCE_REMOVE
 
@@ -155,12 +159,13 @@ class AlbumsView(Gtk.Stack):
         self.props.selection_mode = selection_mode
         if not self.props.selection_mode:
             self.deselect_all()
+            self._flowbox.props.selection_mode = Gtk.SelectionMode.NONE
 
     def _on_search_mode_changed(self, klass, param):
         if (not self.props.search_mode_active
                 and self._headerbar.props.stack.props.visible_child == self
                 and self.get_visible_child() == self._album_widget):
-            self._set_album_headerbar(self._album_widget.props.album)
+            self._set_album_headerbar(self._album_widget.props.corealbum)
 
     def _create_widget(self, corealbum):
         album_widget = AlbumCover(corealbum)
@@ -194,10 +199,10 @@ class AlbumsView(Gtk.Stack):
             return
 
         # Update and display the album widget if not in selection mode
-        self._album_widget.update(corealbum)
+        self._album_widget.props.corealbum = corealbum
 
         self._set_album_headerbar(corealbum)
-        self.set_visible_child(self._album_widget)
+        self.set_visible_child(self._album_scrolled_window)
 
     def _set_album_headerbar(self, corealbum):
         self._headerbar.props.state = HeaderBar.State.CHILD
