@@ -23,14 +23,14 @@
 # delete this exception statement from your version.
 
 from gettext import gettext as _
-from gi.repository import GObject, Gtk
+from gi.repository import GLib, GObject, Gtk
 
 from gnomemusic.widgets.artistalbumswidget import ArtistAlbumsWidget
 from gnomemusic.widgets.artisttile import ArtistTile
 
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/ArtistsView.ui")
-class ArtistsView(Gtk.Box):
+class ArtistsView(Gtk.Paned):
     """Main view of all available artists
 
     Consists of a list of artists on the left side and an overview of
@@ -39,6 +39,9 @@ class ArtistsView(Gtk.Box):
 
     __gtype_name__ = "ArtistsView"
 
+    icon_name = GObject.Property(
+        type=str, default="system-users-symbolic",
+        flags=GObject.ParamFlags.READABLE)
     title = GObject.Property(
         type=str, default=_("Artists"), flags=GObject.ParamFlags.READABLE)
 
@@ -57,6 +60,7 @@ class ArtistsView(Gtk.Box):
 
         self._application = application
         self._artists = {}
+        self._widget_counter = 1
 
         self._selected_artist = None
         self._loaded_artists = []
@@ -85,6 +89,11 @@ class ArtistsView(Gtk.Box):
         row = ArtistTile(coreartist)
         row.props.text = coreartist.props.artist
 
+        GLib.timeout_add(
+            self._widget_counter * 300, row.retrieve,
+            priority=GLib.PRIORITY_LOW)
+        self._widget_counter = self._widget_counter + 1
+
         return row
 
     def _on_model_items_changed(self, model, position, removed, added):
@@ -206,11 +215,11 @@ class ArtistsView(Gtk.Box):
             self._selected_artist = None
 
     def select_all(self):
-        artist_albums = self._artist_view.get_visible_child()
+        artist_albums = self._artist_view.get_visible_child().get_child()
         for row in artist_albums:
             row.get_child().select_all()
 
     def deselect_all(self):
-        artist_albums = self._artist_view.get_visible_child()
+        artist_albums = self._artist_view.get_visible_child().get_child()
         for row in artist_albums:
             row.get_child().deselect_all()
