@@ -27,33 +27,31 @@ from enum import IntEnum
 from gettext import gettext as _
 from gi.repository import GLib, GObject, Gtk, Tracker
 
-from gnomemusic.albumartcache import Art
-
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/EmptyView.ui")
 class EmptyView(Gtk.Stack):
     """Empty view when there is no music to display
 
-    This view can have three states
-    INITIAL means that Music app has never been initialized and no music
-    has been found
-    EMPTY means that no music has been found at startup
-    SEARCH is the empty search view: no music found during a search
+    This view can have several states
+
+    EMPTY: No music has been found at startup (default)
+    SEARCH: No music found with a user search
+    NO_TRACKER: Tracker is unavailable
+    TRACKER_OUTDATED: Tracker version is too old
     """
 
     class State(IntEnum):
         """Enum for EmptyView state."""
-        INITIAL = 0
-        EMPTY = 1
-        SEARCH = 2
-        NO_TRACKER = 3
-        TRACKER_OUTDATED = 4
+        EMPTY = 0
+        SEARCH = 1
+        NO_TRACKER = 2
+        TRACKER_OUTDATED = 3
 
     __gtype_name__ = "EmptyView"
 
-    _information_label = Gtk.Template.Child()
-    _main_label = Gtk.Template.Child()
-    _icon = Gtk.Template.Child()
+    _description_label = Gtk.Template.Child()
+    _initial_state = Gtk.Template.Child()
+    _status_page = Gtk.Template.Child()
 
     def __init__(self):
         super().__init__()
@@ -71,14 +69,21 @@ class EmptyView(Gtk.Stack):
             GLib.filename_to_uri(music_folder))
 
         href_text = "<a href='{}'>{}</a>".format(
-            music_folder, _("Music folder"))
+            music_folder, _("Music Folder"))
 
         # TRANSLATORS: This is a label to display a link to open user's music
         # folder. {} will be replaced with the translated text 'Music folder'
         folder_text = _("The contents of your {} will appear here.")
         self._content_text = folder_text.format(href_text)
 
-        self._state = EmptyView.State.INITIAL
+        # Hack to get to HdyClamp, so it can be hidden for the
+        # initial state.
+        child_of_child = self._status_page.get_child().get_child()
+        self._hdy_clamp = child_of_child.get_child().get_children()[0]
+
+        self._status_page.add(self._initial_state)
+
+        self._state = EmptyView.State.EMPTY
 
     @GObject.Property(type=int, default=0, minimum=0, maximum=4)
     def state(self):
@@ -89,16 +94,18 @@ class EmptyView(Gtk.Stack):
         """
         return self._state
 
-    @state.setter
+    @state.setter  # type: ignore
     def state(self, value):
         """Set the state of the empty view
 
         :param int value: new state
         """
         self._state = value
-        if self._state == EmptyView.State.INITIAL:
-            self._set_initial_state()
-        elif self._state == EmptyView.State.EMPTY:
+
+        self._hdy_clamp.props.visible = True
+        self._initial_state.props.visible = False
+
+        if self._state == EmptyView.State.EMPTY:
             self._set_empty_state()
         elif self._state == EmptyView.State.SEARCH:
             self._set_search_state()
@@ -107,45 +114,31 @@ class EmptyView(Gtk.Stack):
         elif self._state == EmptyView.State.TRACKER_OUTDATED:
             self._set_tracker_outdated_state()
 
-    def _set_initial_state(self):
-        self._information_label.props.label = self._content_text
-        self._main_label.props.label = _("Hey DJ")
-        self._main_label.props.margin_bottom = 18
-
-        self._icon.props.resource = "/org/gnome/Music/icons/initial-state.png"
-        self._icon.props.margin_bottom = 32
-        self._icon.props.height_request = Art.Size.LARGE.height
-        self._icon.props.width_request = Art.Size.LARGE.width
-
     def _set_empty_state(self):
-        self._main_label.props.label = _("No music found")
-        self._information_label.props.label = self._content_text
+        self._hdy_clamp.props.visible = False
+        self._initial_state.props.visible = True
+
+        self._description_label.props.label = self._content_text
 
     def _set_search_state(self):
-        self._main_label.props.margin_bottom = 12
-        self._main_label.props.label = _("No music found")
-        self._icon.props.margin_bottom = 18
-        self._information_label.props.label = _("Try a different search")
+        self._status_page.props.title = _("No Music Found")
+        self._status_page.props.description = _("Try a Different Search")
 
     def _set_no_tracker_state(self):
-        self._main_label.props.margin_bottom = 12
-        self._main_label.props.label = _(
-            "GNOME Music could not connect to Tracker")
-        self._icon.props.margin_bottom = 18
-        self._information_label.props.label = _(
-            "Your music files cannot be indexed without Tracker running")
+        self._status_page.props.title = _(
+            "GNOME Music could not connect to Tracker.")
+        self._status_page.props.description = _(
+            "Your music files cannot be indexed without Tracker running.")
 
-        self._icon.props.icon_name = "dialog-error-symbolic"
+        self._status_page.props.icon_name = "dialog-error-symbolic"
 
     def _set_tracker_outdated_state(self):
-        self._main_label.props.margin_bottom = 12
-        self._main_label.props.label = _(
-            "Your system Tracker version seems outdated")
-        self._icon.props.margin_bottom = 18
-        self._information_label.props.label = _(
-            "Music needs Tracker version 2.3.0 or higher")
+        self._status_page.props.title = _(
+            "Your system Tracker version seems outdated.")
+        self._status_page.props.description = _(
+            "Music needs Tracker version 3.0.0 or higher.")
 
-        self._icon.props.icon_name = "dialog-error-symbolic"
+        self._status_page.props.icon_name = "dialog-error-symbolic"
 
     def select_all(self):
         """Cannot select songs from EmptyView."""
