@@ -23,6 +23,7 @@
 # delete this exception statement from your version.
 
 from gettext import gettext as _
+from typing import Optional
 
 from gi.repository import GObject, Gtk
 
@@ -32,11 +33,14 @@ from gnomemusic.widgets.playlisttile import PlaylistTile
 
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/PlaylistsView.ui")
-class PlaylistsView(Gtk.Box):
+class PlaylistsView(Gtk.Paned):
     """Main view for playlists"""
 
     __gtype_name__ = "PlaylistsView"
 
+    icon_name = GObject.Property(
+        type=str, default="view-list-symbolic",
+        flags=GObject.ParamFlags.READABLE)
     title = GObject.Property(
         type=str, default=_("Playlists"), flags=GObject.ParamFlags.READABLE)
 
@@ -61,14 +65,29 @@ class PlaylistsView(Gtk.Box):
         self._playlist_widget = PlaylistsWidget(application, self)
         self.add(self._playlist_widget)
 
+        self._sidebar.set_header_func(self._sidebar_header_func)
         self._sidebar.bind_model(self._model, self._add_playlist_to_sidebar)
 
         self._coremodel.connect(
-            "notify::active-playlist", self._on_active_playlist_changed)
+            "notify::active-core-object", self._on_active_core_object_changed)
 
         self._model.connect("items-changed", self._on_playlists_model_changed)
         self._on_playlists_model_changed(self._model, 0, 0, 0)
 
+    def _sidebar_header_func(
+            self, row: Gtk.ListBoxRow,
+            before: Optional[Gtk.ListBoxRow]) -> None:
+        if (before
+                and before.props.playlist.props.is_smart
+                and not row.props.playlist.props.is_smart):
+            separator = Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL)
+            separator.props.height_request = 2
+            separator.props.margin_end = 16
+            separator.props.margin_start = 16
+            row.set_header(separator)
+        else:
+            row.set_header(None)
+
     def _add_playlist_to_sidebar(self, playlist):
         """Add a playlist to sidebar
 
@@ -114,19 +133,19 @@ class PlaylistsView(Gtk.Box):
 
         self.notify("current-playlist")
 
-    def _on_active_playlist_changed(self, klass, val):
+    def _on_active_core_object_changed(self, klass, val):
         """Selects the active playlist when an MPRIS client
            has changed it.
         """
-        playlist = self._coremodel.props.active_playlist
+        active_core_object = self._coremodel.props.active_core_object
         selection = self._sidebar.get_selected_row()
-        if (playlist is None
-                or playlist == selection.props.playlist):
+        if (not isinstance(active_core_object, Playlist)
+                or active_core_object == selection.props.playlist):
             return
 
         playlist_row = None
         for row in self._sidebar:
-            if row.props.playlist == playlist:
+            if row.props.playlist == active_core_object:
                 playlist_row = row
                 break
 
