@@ -23,12 +23,12 @@
 # delete this exception statement from your version.
 
 from gettext import gettext as _
-from gi.repository import GObject, Gtk
+from gi.repository import Gio, GLib, GObject, Gtk
 
-from gnomemusic.albumartcache import Art
+from gnomemusic.defaulticon import DefaultIcon
 from gnomemusic.gstplayer import Playback
+from gnomemusic.utils import ArtSize
 from gnomemusic.player import Player, RepeatMode
-from gnomemusic.widgets.coverstack import CoverStack  # noqa: F401
 from gnomemusic.widgets.smoothscale import SmoothScale  # noqa: F401
 from gnomemusic.widgets.twolinetip import TwoLineTip
 import gnomemusic.utils as utils
@@ -44,7 +44,8 @@ class PlayerToolbar(Gtk.ActionBar):
     __gtype_name__ = 'PlayerToolbar'
 
     _artist_label = Gtk.Template.Child()
-    _cover_stack = Gtk.Template.Child()
+    _art_stack = Gtk.Template.Child()
+    _buttons_and_scale = Gtk.Template.Child()
     _duration_label = Gtk.Template.Child()
     _next_button = Gtk.Template.Child()
     _pause_image = Gtk.Template.Child()
@@ -53,26 +54,40 @@ class PlayerToolbar(Gtk.ActionBar):
     _prev_button = Gtk.Template.Child()
     _progress_scale = Gtk.Template.Child()
     _progress_time_label = Gtk.Template.Child()
+    _repeat_menu_button = Gtk.Template.Child()
     _repeat_image = Gtk.Template.Child()
     _song_info_box = Gtk.Template.Child()
     _title_label = Gtk.Template.Child()
 
-    _repeat_dict = {
-        RepeatMode.ALL: "media-playlist-repeat-symbolic",
-        RepeatMode.NONE: "media-playlist-consecutive-symbolic",
-        RepeatMode.SHUFFLE: "media-playlist-shuffle-symbolic",
-        RepeatMode.SONG: "media-playlist-repeat-song-symbolic"
-    }
-
     def __init__(self):
         super().__init__()
 
         self._player = None
 
-        self._cover_stack.props.size = Art.Size.XSMALL
+        self._art_stack.props.size = ArtSize.SMALL
+        self._art_stack.props.art_type = DefaultIcon.Type.ALBUM
 
         self._tooltip = TwoLineTip()
 
+        # A centered widget has an expand child property set to False
+        # by default. It needs to be True to have a progress scale
+        # at the correct size.
+        main_container = self._buttons_and_scale.get_parent()
+        main_container.child_set_property(
+            self._buttons_and_scale, "expand", True)
+
+        repeat_menu = Gio.Menu.new()
+        for mode in RepeatMode:
+            item = Gio.MenuItem.new()
+            item.set_label(mode.label)
+            item.set_action_and_target_value(
+                "playertoolbar.repeat", GLib.Variant("s", str(mode.value)))
+            repeat_menu.append_item(item)
+
+        self._repeat_menu_button.props.menu_model = repeat_menu
+        self._repeat_action: Gio.SimpleAction = Gio.SimpleAction.new_stateful(
+            "repeat", GLib.VariantType.new("s"), GLib.Variant("s", ""))
+
     # FIXME: This is a workaround for not being able to pass the player
     # object via init when using Gtk.Builder.
     @GObject.Property(type=Player, default=None)
@@ -84,7 +99,7 @@ class PlayerToolbar(Gtk.ActionBar):
         """
         return self._player
 
-    @player.setter
+    @player.setter  # type: ignore
     def player(self, player):
         """Set the GstPlayer object used
 
@@ -103,8 +118,23 @@ class PlayerToolbar(Gtk.ActionBar):
             'notify::repeat-mode', self._on_repeat_mode_changed)
         self._player.connect('notify::state', self._sync_playing)
 
+        repeat_mode = self._player.props.repeat_mode
+        self._repeat_action.set_state(
+            GLib.Variant("s", str(repeat_mode.value)))
+        self._repeat_action.connect("activate", self._repeat_menu_changed)
+        action_group = Gio.SimpleActionGroup()
+        action_group.add_action(self._repeat_action)
+        self.insert_action_group("playertoolbar", action_group)
+
         self._sync_repeat_image()
 
+    def _repeat_menu_changed(
+            self, action: Gio.SimpleAction, new_state: GLib.Variant) -> None:
+        self._repeat_action.set_state(new_state)
+        new_mode = new_state.get_string()
+        self._player.props.repeat_mode = RepeatMode(int(new_mode))
+        self._repeat_menu_button.props.active = False
+
     @Gtk.Template.Callback()
     def _on_progress_value_changed(self, progress_scale):
         seconds = int(progress_scale.get_value() / 60)
@@ -126,9 +156,9 @@ class PlayerToolbar(Gtk.ActionBar):
         self._sync_repeat_image()
         self._sync_prev_next()
 
-    def _sync_repeat_image(self):
-        icon = self._repeat_dict[self._player.props.repeat_mode]
-        self._repeat_image.set_from_icon_name(icon, Gtk.IconSize.MENU)
+    def _sync_repeat_image(self) -> None:
+        self._repeat_image.set_from_icon_name(
+            self._player.props.repeat_mode.icon, Gtk.IconSize.MENU)
 
     def _sync_playing(self, player, state):
         if (self._player.props.state == Playback.STOPPED
@@ -163,7 +193,7 @@ class PlayerToolbar(Gtk.ActionBar):
         coresong = player.props.current_song
         self._duration_label.props.label = utils.seconds_to_string(
             coresong.props.duration)
-        self._progress_time_label.props.label = "0:00"
+        self._progress_time_label.props.label = "0∶00"
 
         self._play_button.set_sensitive(True)
         self._sync_prev_next()
@@ -177,7 +207,7 @@ class PlayerToolbar(Gtk.ActionBar):
         self._tooltip.props.title = title
         self._tooltip.props.subtitle = artist
 
-        self._cover_stack.update(coresong)
+        self._art_stack.props.coreobject = coresong
 
     @Gtk.Template.Callback()
     def _on_tooltip_query(self, widget, x, y, kb, tooltip, data=None):
