@@ -81,7 +81,7 @@ class CellRendererStar(Gtk.CellRendererPixbuf):
     def show_star(self):
         return self._show_star
 
-    @show_star.setter
+    @show_star.setter  # type: ignore
     def show_star(self, value):
         """Set the show-star value
 
@@ -122,7 +122,7 @@ class StarHandlerWidget(object):
 
     def _on_star_toggled(self, widget, path):
         """Called if a star is clicked"""
-        model = self._parent._view.props.model
+        model = self._parent.props.model
         try:
             _iter = model.get_iter(path)
         except ValueError:
