@@ -22,7 +22,7 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-from gi.repository import Gtk, Gdk, Gio, GLib, GObject
+from gi.repository import Gtk, Gdk, Gio, GLib, GObject, Handy
 from gettext import gettext as _
 
 from gnomemusic.gstplayer import Playback
@@ -47,7 +47,7 @@ from gnomemusic.windowplacement import WindowPlacement
 
 
 @Gtk.Template(resource_path="/org/gnome/Music/ui/Window.ui")
-class Window(Gtk.ApplicationWindow):
+class Window(Handy.ApplicationWindow):
 
     __gtype_name__ = "Window"
 
@@ -57,6 +57,7 @@ class Window(Gtk.ApplicationWindow):
 
     notifications_popup = Gtk.Template.Child()
     _headerbar_stack = Gtk.Template.Child()
+    _key_controller = Gtk.Template.Child()
     _overlay = Gtk.Template.Child()
     _player_toolbar = Gtk.Template.Child()
     _selection_toolbar = Gtk.Template.Child()
@@ -76,7 +77,6 @@ class Window(Gtk.ApplicationWindow):
             "selected-songs-count", self, "selected-songs-count")
 
         self._settings = app.props.settings
-        self.add_action(self._settings.create_action('repeat'))
         select_all = Gio.SimpleAction.new('select_all', None)
         select_all.connect('activate', self._select_all)
         self.add_action(select_all)
@@ -93,6 +93,7 @@ class Window(Gtk.ApplicationWindow):
         self._player = app.props.player
         self._search = app.props.search
 
+        self._startup_timeout_id = 0
         self._setup_view()
 
         MediaKeys(self._player, self)
@@ -174,25 +175,19 @@ class Window(Gtk.ApplicationWindow):
         self._app.props.coregrilo.connect(
             "notify::tracker-available", self._on_tracker_available)
 
-        if self._app.props.coremodel.props.songs_available:
-            self._switch_to_player_view()
-        else:
-            self._switch_to_empty_view()
+        self._startup_timeout_id = GLib.timeout_add(
+            2000, self._on_songs_available, None, None)
 
     def _switch_to_empty_view(self):
-        did_initial_state = self._settings.get_boolean('did-initial-state')
-
         state = self._app.props.coregrilo.props.tracker_available
         empty_view = self.views[View.EMPTY]
+        empty_view.props.visible = True
         if state == TrackerState.UNAVAILABLE:
             empty_view.props.state = EmptyView.State.NO_TRACKER
         elif state == TrackerState.OUTDATED:
             empty_view.props.state = EmptyView.State.TRACKER_OUTDATED
-        elif did_initial_state:
-            empty_view.props.state = EmptyView.State.EMPTY
         else:
-            # FIXME: On switch back this view does not show properly.
-            empty_view.props.state = EmptyView.State.INITIAL
+            empty_view.props.state = EmptyView.State.EMPTY
 
         self._headerbar.props.state = HeaderBar.State.EMPTY
 
@@ -203,6 +198,10 @@ class Window(Gtk.ApplicationWindow):
             self._headerbar_stack.props.visible_child_name = "main"
 
     def _on_songs_available(self, klass, value):
+        if self._startup_timeout_id > 0:
+            GLib.source_remove(self._startup_timeout_id)
+            self._startup_timeout_id = 0
+
         if self._app.props.coremodel.props.songs_available:
             self._switch_to_player_view()
         else:
@@ -220,12 +219,14 @@ class Window(Gtk.ApplicationWindow):
         self._on_songs_available(None, None)
 
     def _switch_to_player_view(self):
-        self._settings.set_boolean('did-initial-state', True)
         self._on_notify_model_id = self._stack.connect(
             'notify::visible-child', self._on_notify_mode)
         self.connect('destroy', self._notify_mode_disconnect)
-        self._key_press_event_id = self.connect(
-            'key_press_event', self._on_key_press)
+
+        # All views are created together, so if the album view is
+        # already initialized, assume the rest are as well.
+        if self.views[View.ALBUM] is not None:
+            return
 
         self._btn_ctrl = Gtk.GestureMultiPress().new(self)
         self._btn_ctrl.props.propagation_phase = Gtk.PropagationPhase.CAPTURE
@@ -236,12 +237,6 @@ class Window(Gtk.ApplicationWindow):
         self.views[View.EMPTY].props.state = EmptyView.State.SEARCH
 
         self._headerbar.props.state = HeaderBar.State.MAIN
-
-        # All views are created together, so if the album view is
-        # already initialized, assume the rest are as well.
-        if self.views[View.ALBUM] is not None:
-            return
-
         self.views[View.ALBUM] = AlbumsView(self._app)
         self.views[View.ARTIST] = ArtistsView(self._app)
         self.views[View.SONG] = SongsView(self._app)
@@ -255,10 +250,15 @@ class Window(Gtk.ApplicationWindow):
         for i in self.views[View.ALBUM:]:
             if i.props.title:
                 self._stack.add_titled(i, i.props.name, i.props.title)
+                self._stack.child_set_property(
+                    i, "icon-name", i.props.icon_name)
             else:
                 self._stack.add_named(i, i.props.name)
 
+        # The "visible-child" notification ensures that the AlbumView
+        # appears as selected by the stack switcher on launch.
         self._stack.props.visible_child = self.views[View.ALBUM]
+        self._stack.notify("visible-child")
 
         self.views[View.SEARCH].bind_property(
             "search-state", self._search, "state",
@@ -282,10 +282,9 @@ class Window(Gtk.ApplicationWindow):
 
         self.props.active_view.deselect_all()
 
-    def _on_key_press(self, widget, event):
-        modifiers = event.get_state() & Gtk.accelerator_get_default_mod_mask()
-        (_, keyval) = event.get_keyval()
-
+    @Gtk.Template.Callback()
+    def _on_key_press(self, controller, keyval, keycode, state):
+        modifiers = state & Gtk.accelerator_get_default_mod_mask()
         control_mask = Gdk.ModifierType.CONTROL_MASK
         shift_mask = Gdk.ModifierType.SHIFT_MASK
         mod1_mask = Gdk.ModifierType.MOD1_MASK
@@ -315,20 +314,14 @@ class Window(Gtk.ApplicationWindow):
             if keyval == Gdk.KEY_r:
                 if self._player.props.repeat_mode == RepeatMode.SONG:
                     self._player.props.repeat_mode = RepeatMode.NONE
-                    repeat_state = GLib.Variant("s", ("none"))
                 else:
                     self._player.props.repeat_mode = RepeatMode.SONG
-                    repeat_state = GLib.Variant("s", ("song"))
-                self.lookup_action('repeat').change_state(repeat_state)
             # Toggle shuffle on Ctrl + S
             if keyval == Gdk.KEY_s:
                 if self._player.props.repeat_mode == RepeatMode.SHUFFLE:
                     self._player.props.repeat_mode = RepeatMode.NONE
-                    repeat_state = GLib.Variant("s", ("none"))
                 else:
                     self._player.props.repeat_mode = RepeatMode.SHUFFLE
-                    repeat_state = GLib.Variant("s", ("shuffle"))
-                self.lookup_action('repeat').change_state(repeat_state)
         # Ctrl+Shift+<KEY>
         elif modifiers == shift_ctrl_mask:
             if keyval == Gdk.KEY_A:
@@ -362,10 +355,11 @@ class Window(Gtk.ApplicationWindow):
             if keyval == Gdk.KEY_AudioNext:
                 self._player.next()
 
-            child = self.props.active_view
             if (keyval == Gdk.KEY_Delete
-                    and child == self.views[View.PLAYLIST]):
-                self.views[View.PLAYLIST].remove_playlist()
+                    and self.props.active_view == self.views[View.PLAYLIST]
+                    and not self.views[View.PLAYLIST].rename_active):
+                self.activate_action("playlist_delete", None)
+
             # Close selection mode or search bar after Esc is pressed
             if keyval == Gdk.KEY_Escape:
                 if self.props.selection_mode:
